[vlc-commits] Rename main module to core
Rafaël Carré
git at videolan.org
Mon Dec 9 04:06:39 CET 2013
vlc | branch: master | Rafaël Carré <funman at videolan.org> | Sat Dec 7 00:57:11 2013 +0100| [a8b1850adafa3f492dcf448dd9a97a29886c8da7] | committer: Rafaël Carré
Rename main module to core
> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=a8b1850adafa3f492dcf448dd9a97a29886c8da7
---
src/Makefile.am | 2 +-
src/config/help.c | 2 +-
src/libvlc-module.c | 8 ++++----
src/libvlc.c | 4 ++--
src/modules/bank.c | 10 +++++-----
src/modules/modules.h | 4 ++--
6 files changed, 15 insertions(+), 15 deletions(-)
diff --git a/src/Makefile.am b/src/Makefile.am
index a7f42ef..54f5c48 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -163,7 +163,7 @@ EXTRA_DIST += libvlc_win32_rc.rc.in
lib_LTLIBRARIES = libvlccore.la
AM_CPPFLAGS = $(INCICONV) $(IDN_CFLAGS) \
- -DMODULE_STRING=\"main\" \
+ -DMODULE_STRING=\"core\" \
-DLOCALEDIR=\"$(localedir)\" \
-DPKGDATADIR=\"$(vlcdatadir)\" \
-DPKGLIBDIR=\"$(vlclibdir)\"
diff --git a/src/config/help.c b/src/config/help.c
index 155dc50..fd69763 100644
--- a/src/config/help.c
+++ b/src/config/help.c
@@ -202,7 +202,7 @@ static void Help (vlc_object_t *p_this, char const *psz_help_name)
if( psz_help_name && !strcmp( psz_help_name, "help" ) )
{
printf(_(vlc_usage), "vlc");
- Usage( p_this, "=main" );
+ Usage( p_this, "=core" );
print_help_on_full_help();
}
else if( psz_help_name && !strcmp( psz_help_name, "longhelp" ) )
diff --git a/src/libvlc.c b/src/libvlc.c
index f1b0d65..ead3a0d 100644
--- a/src/libvlc.c
+++ b/src/libvlc.c
@@ -137,8 +137,8 @@ int libvlc_InternalInit( libvlc_int_t *p_libvlc, int i_argc,
system_Init();
/* Initialize the module bank and load the configuration of the
- * main module. We need to do this at this stage to be able to display
- * a short help if required by the user. (short help == main module
+ * core module. We need to do this at this stage to be able to display
+ * a short help if required by the user. (short help == core module
* options) */
module_InitBank ();
diff --git a/src/modules/modules.h b/src/modules/modules.h
index bad964f..e38e952 100644
--- a/src/modules/modules.h
+++ b/src/modules/modules.h
@@ -49,8 +49,8 @@ typedef void *module_handle_t;
/** Plugin entry point prototype */
typedef int (*vlc_plugin_cb) (int (*)(void *, void *, int, ...), void *);
-/** Main module */
-int vlc_entry__main (int (*)(void *, void *, int, ...), void *);
+/** Core module */
+int vlc_entry__core (int (*)(void *, void *, int, ...), void *);
/**
* Internal module descriptor
More information about the vlc-commits
mailing list
diff --git a/src/libvlc-module.c b/src/libvlc-module.c
index 50de5d9..182c7e1 100644
--- a/src/libvlc-module.c
+++ b/src/libvlc-module.c
@@ -1,5 +1,5 @@
/*****************************************************************************
* libvlc-module.c: Options for the main (libvlc itself) module
*****************************************************************************
* Copyright (C) 1998-2009 VLC authors and VideoLAN
* $Id$
@@ -25,7 +25,7 @@
*****************************************************************************/
// Pretend we are a builtin module
-#define MODULE_NAME main
+#define MODULE_NAME core
#ifdef HAVE_CONFIG_H
# include "config.h"
@@ -47,7 +47,7 @@ static const char *const ppsz_snap_formats[] =
{ "png", "jpg", "tiff" };
/*****************************************************************************
* Configuration options for the main program. Each module will also separatly
* define its own configuration options.
* Look into configuration.h if you need to know more about the following
* macros.
@@ -2696,7 +2696,7 @@ vlc_module_begin ()
/* Usage (mainly useful for cmd line stuff) */
/* add_usage_hint( PLAYLIST_USAGE ) */
- set_description( N_("main program") )
+ set_description( N_("core program") )
vlc_module_end ()
/*****************************************************************************
@@ -1,5 +1,5 @@
/*****************************************************************************
- * libvlc-module.c: Options for the main (libvlc itself) module
+ * libvlc-module.c: Options for the core (libvlc itself) module
*****************************************************************************
* Copyright (C) 1998-2009 VLC authors and VideoLAN
@@ -47,7 +47,7 @@ static const char *const ppsz_snap_formats[] =
{ "png", "jpg", "tiff" };
/*****************************************************************************
- * Configuration options for the main program. Each module will also separatly
+ * Configuration options for the core module. Each module will also separatly
* define its own configuration options.
* Look into configuration.h if you need to know more about the following
diff --git a/src/modules/bank.c b/src/modules/bank.c
index 22cfaea..ea3ee5d 100644
--- a/src/modules/bank.c
+++ b/src/modules/bank.c
@@ -104,12 +104,12 @@ void module_InitBank (void)
if (modules.usage == 0)
{
/* Fills the module bank structure with the main module infos.
* This is very useful as it will allow us to consider the main
* library just as another module, and for instance the configuration
* options of main will be available in the module bank structure just
* as for every other module. */
- module_t *module = module_InitStatic (vlc_entry__main);
+ module_t *module = module_InitStatic (vlc_entry__core);
if (likely(module != NULL))
module_StoreBank (module);
config_SortConfig ();
@@ -119,7 +119,7 @@ void module_InitBank (void)
/* We do retain the module bank lock until the plugins are loaded as well.
* This is ugly, this staged loading approach is needed: LibVLC gets
* some configuration parameters relevant to loading the plugins from
* the main (builtin) module. The module bank becomes shared read-only data
* once it is ready, so we need to fully serialize initialization.
* DO NOT UNCOMMENT the following line unless you managed to squeeze
* module_LoadPlugins() before you unlock the mutex. */
@@ -104,12 +104,12 @@ void module_InitBank (void)
if (modules.usage == 0)
{
- /* Fills the module bank structure with the main module infos.
- * This is very useful as it will allow us to consider the main
+ /* Fills the module bank structure with the core module infos.
+ * This is very useful as it will allow us to consider the core
* library just as another module, and for instance the configuration
@@ -104,12 +104,12 @@ void module_InitBank (void)
* library just as another module, and for instance the configuration
- * options of main will be available in the module bank structure just
+ * options of core will be available in the module bank structure just
* as for every other module. */
@@ -119,7 +119,7 @@ void module_InitBank (void)
* This is ugly, this staged loading approach is needed: LibVLC gets
* some configuration parameters relevant to loading the plugins from
- * the main (builtin) module. The module bank becomes shared read-only data
+ * the core (builtin) module. The module bank becomes shared read-only data
* once it is ready, so we need to fully serialize initialization.
* DO NOT UNCOMMENT the following line unless you managed to squeeze